@@ -1,23 +1,12 @@
 /*
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterplaintest.h"
-#include <MailImporter/FilterPlain>
 #include "filterimportertest.h"
+#include <MailImporter/FilterPlain>
 #include <QTest>
 
 FilterPlainTest::FilterPlainTest(QObject *parent)
@@ -37,7 +26,7 @@ void FilterPlainTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterPlain filter;
     MailImporter::FilterInfo info;
-    FilterImporterTest *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QString());
@@ -49,7 +38,7 @@ void FilterPlainTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterPlain filter;
     MailImporter::FilterInfo info;
-    FilterImporterTest *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
