@@ -1,27 +1,19 @@
-/***************************************************************************
-                          filter_oe.cxx  -  Outlook Express mail import
-                             -------------------
-    begin                : Sat Feb 1 2003
-    copyright            : (C) 2003 by Laurence Anderson <l.d.anderson@warwick.ac.uk>
-                           (C) 2005 by Danny Kukawka <danny.Kukawka@web.de>
- ***************************************************************************/
+/*
+  filter_oe.cpp  -  Outlook Express mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2003 Laurence Anderson <l.d.anderson@warwick.ac.uk>
+  SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.Kukawka@web.de>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // This filter was created by looking at libdbx  &liboe
 
 #include "filteroe.h"
 #include "mailimporter_debug.h"
 
-#include <QFileDialog>
 #include <KLocalizedString>
+#include <QFileDialog>
 
 #include <QTemporaryFile>
 
@@ -106,7 +98,7 @@ void FilterOE::importMails(const QString &maildir)
             break;
         }
         importMailBox(dir.filePath(*mailFile));
-        filterInfo()->setOverall(100 * ++n  / files.count());
+        filterInfo()->setOverall(100 * ++n / files.count());
     }
 
     filterInfo()->setOverall(100);
@@ -138,7 +130,8 @@ void FilterOE::importMailBox(const QString &fileName)
     mailbox.setByteOrder(QDataStream::LittleEndian);
 
     // Parse magic
-    quint32 sig_block1, sig_block2;
+    quint32 sig_block1;
+    quint32 sig_block2;
     mailbox >> sig_block1 >> sig_block2;
     if (sig_block1 == OE4_SIG_1 && sig_block2 == OE4_SIG_2) {
         folderName = QLatin1String("OE-Import/") + mailfileinfo.completeBaseName();
@@ -147,7 +140,8 @@ void FilterOE::importMailBox(const QString &fileName)
         mbxImport(mailbox);
         return;
     } else {
-        quint32 sig_block3, sig_block4;
+        quint32 sig_block3;
+        quint32 sig_block4;
         mailbox >> sig_block3 >> sig_block4;
         if (sig_block1 == OE5_SIG_1 && sig_block3 == OE5_SIG_3 && sig_block4 == OE5_SIG_4) {
             if (sig_block2 == OE5_EMAIL_SIG_2) {
@@ -179,21 +173,25 @@ void FilterOE::importMailBox(const QString &fileName)
 
 void FilterOE::mbxImport(QDataStream &ds)
 {
-    quint32 msgCount, lastMsgNum, fileSize;
+    quint32 msgCount;
+    quint32 lastMsgNum;
+    quint32 fileSize;
 
     // Read the header
     ds >> msgCount >> lastMsgNum >> fileSize;
-    ds.device()->seek(ds.device()->pos() + 64);   // Skip 0's
+    ds.device()->seek(ds.device()->pos() + 64); // Skip 0's
     qCDebug(MAILIMPORTER_LOG) << "This mailbox has" << msgCount << " messages";
     if (msgCount == 0) {
-        return;    // Don't import empty mailbox
+        return; // Don't import empty mailbox
     }
 
     quint32 msgMagic;
     ds >> msgMagic; // Read first magic
 
     while (!ds.atEnd()) {
-        quint32 msgNumber, msgSize, msgTextSize;
+        quint32 msgNumber;
+        quint32 msgSize;
+        quint32 msgTextSize;
         QTemporaryFile tmp;
         tmp.open();
         QDataStream dataStream(&tmp);
@@ -225,7 +223,8 @@ void FilterOE::mbxImport(QDataStream &ds)
 void FilterOE::dbxImport(QDataStream &ds)
 {
     // Get item count  &offset of index
-    quint32 itemCount, indexPtr;
+    quint32 itemCount;
+    quint32 indexPtr;
     ds.device()->seek(0xc4);
     ds >> itemCount;
     ds.device()->seek(0xe4);
@@ -233,7 +232,7 @@ void FilterOE::dbxImport(QDataStream &ds)
     qCDebug(MAILIMPORTER_LOG) << "Item count is" << itemCount << ", Index at" << indexPtr;
 
     if (itemCount == 0) {
-        return;    // Empty file
+        return; // Empty file
     }
     totalEmails = itemCount;
     currentEmail = 0;
@@ -247,8 +246,13 @@ void FilterOE::dbxReadIndex(QDataStream &ds, int filePos)
     if (filterInfo()->shouldTerminate()) {
         return;
     }
-    quint32 self, unknown, nextIndexPtr, parent, indexCount;
-    quint8 unknown2, ptrCount;
+    quint32 self;
+    quint32 unknown;
+    quint32 nextIndexPtr;
+    quint32 parent;
+    quint32 indexCount;
+    quint8 unknown2;
+    quint8 ptrCount;
     quint16 unknown3;
     int wasAt = ds.device()->pos();
     ds.device()->seek(filePos);
@@ -261,7 +265,9 @@ void FilterOE::dbxReadIndex(QDataStream &ds, int filePos)
         if (filterInfo()->shouldTerminate()) {
             return;
         }
-        quint32 dataIndexPtr, anotherIndexPtr, anotherIndexCount; // _dbx_indexstruct
+        quint32 dataIndexPtr;
+        quint32 anotherIndexPtr;
+        quint32 anotherIndexCount; // _dbx_indexstruct
         ds >> dataIndexPtr >> anotherIndexPtr >> anotherIndexCount;
 
         if (anotherIndexCount > 0) {
@@ -273,7 +279,7 @@ void FilterOE::dbxReadIndex(QDataStream &ds, int filePos)
     }
 
     if (indexCount > 0) { // deal with nextTablePtr
-        qCDebug(MAILIMPORTER_LOG) << "Recuring to next table @" << nextIndexPtr;
+        qCDebug(MAILIMPORTER_LOG) << "Recurring to next table @" << nextIndexPtr;
         dbxReadIndex(ds, nextIndexPtr);
     }
 
@@ -282,9 +288,11 @@ void FilterOE::dbxReadIndex(QDataStream &ds, int filePos)
 
 void FilterOE::dbxReadDataBlock(QDataStream &ds, int filePos)
 {
-    quint32 curOffset, blockSize;
+    quint32 curOffset;
+    quint32 blockSize;
     quint16 unknown;
-    quint8 count, unknown2;
+    quint8 count;
+    quint8 unknown2;
     int wasAt = ds.device()->pos();
 
     QString folderEntry[4];
@@ -298,7 +306,7 @@ void FilterOE::dbxReadDataBlock(QDataStream &ds, int filePos)
         if (filterInfo()->shouldTerminate()) {
             return;
         }
-        quint8 type;  // _dbx_email_pointerstruct
+        quint8 type; // _dbx_email_pointerstruct
         quint32 value; // Actually 24 bit
 
         ds >> type >> value;
@@ -315,7 +323,7 @@ void FilterOE::dbxReadDataBlock(QDataStream &ds, int filePos)
                 ds.device()->seek(filePos + 12 + value + (count * 4));
                 quint32 newOFF;
                 ds >> newOFF;
-                qCDebug(MAILIMPORTER_LOG) << "**** Offset of emaildata (0x04)" <<  newOFF;
+                qCDebug(MAILIMPORTER_LOG) << "**** Offset of emaildata (0x04)" << newOFF;
                 ds.device()->seek(currentFilePos);
                 dbxReadEmail(ds, newOFF);
                 ++count0x04;
@@ -348,9 +356,12 @@ void FilterOE::dbxReadEmail(QDataStream &ds, int filePos)
     if (filterInfo()->shouldTerminate()) {
         return;
     }
-    quint32 self, nextAddressOffset, nextAddress = 0;
+    quint32 self;
+    quint32 nextAddressOffset;
+    quint32 nextAddress = 0;
     quint16 blockSize;
-    quint8 intCount, unknown;
+    quint8 intCount;
+    quint8 unknown;
     QTemporaryFile tmp;
     tmp.open();
     bool _break = false;
