@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -34,10 +34,7 @@ ImportMailsWidget::ImportMailsWidget(QWidget *parent)
     d->ui->setupUi(this);
 }
 
-ImportMailsWidget::~ImportMailsWidget()
-{
-    delete d;
-}
+ImportMailsWidget::~ImportMailsWidget() = default;
 
 void ImportMailsWidget::setStatusMessage(const QString &status)
 {
